import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/seankross/a412dfbd88b3db70b74b/raw/5f23f993cd87c283ce766e7ac6b329ee7cc2e1d1/mtcars.csv';
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 50,
  left: 200,
};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.mpg = +d.mpg;
      return d;
    };
    csv(csvUrl, row).then((data) => {
      setData(data);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map((d) => d.model))
    .range([0, innerHeight])
    .padding(0.1);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.mpg)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {data.map((d) => (
          <rect
            key={d.model}
            x={0}
            y={yScale(d.model)}
            width={xScale(d.mpg)}
            height={yScale.bandwidth()}
          />
        ))}
        <g transform={`translate(0,${innerHeight})`}>
          {xScale.ticks().map((tickValue) => (
            <g
              key={tickValue}
              transform={`translate(${xScale(tickValue)},0)`}
            >
              <line y2={-innerHeight} stroke="gray" />
              <text
                style={{ textAnchor: 'middle' }}
                dy=".71em"
                y={-5}
              >
                {tickValue}
              </text>
            </g>
          ))}
        </g>
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
